@@ -5,8 +5,10 @@ from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, List, Optional
 
+import cuid
 from pydantic import AnyHttpUrl, BaseModel, Extra, Field, stricturl
 
+from .base_schemas import SlotDataSchema
 from .types import MessageDispatchEnum, MessageTypeEnum
 
 
@@ -205,6 +207,11 @@ class Chat(BaseModel):
         title="Handsoff app data",
         description="handsoff data received from the plugin and that need to be stored.",
     )
+    slots: Optional[List[SlotDataSchema]] = Field(
+        [],
+        title="Slots Data",
+        description="Slots (variables) used/created by plugins.",
+    )
 
 
 class Contact(BaseModel):
@@ -260,6 +267,11 @@ class Contact(BaseModel):
     status: int = Field(
         ..., title="Status", description="Contact status.", example="1", gt=-1, lt=1025
     )
+    slots: Optional[List[SlotDataSchema]] = Field(
+        [],
+        title="Slots Data",
+        description="Slots (variables) used/created by plugins.",
+    )
 
 
 class CustomFields(BaseModel):
@@ -336,6 +348,13 @@ class MessageSchema(BaseModel):
     class Config:
         validate_assignment = True
 
+    id: str = Field(
+        cuid.cuid(),
+        max_length=256,
+        title="ID",
+        description="Message ID",
+        example="Message ID from who created it.",
+    )
     dispatch: MessageDispatchEnum = Field(
         MessageDispatchEnum.gateway,
         title="Dispatch Module",
